from distutils.core import setup

setup(
        name = 'printbreak',
        version = '1.0.0',
        py_modules = ['printbreak'],
        author = 'Robert',
        author_email = 'robert.rector22@gmail.com',
        url = ' ',
        description = 'A simple printer of nested files',
)
